=========================================
``psyclone.tests.gocean1p0_stencil_test``
=========================================

.. automodule:: psyclone.tests.gocean1p0_stencil_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.gocean1p0_stencil_test
